# Acknowledgements

`flyvision` is developed at the [Macke Lab](https://www.mackelab.org) at the University of Tübingen and at the [Turaga Lab](https://www.janelia.org/lab/turaga-lab) at Janelia Research Campus.

## Paper

Acknowledgements for the scientific content can be found in the [paper](https://www.nature.com/articles/s41586-024-07939-3#Ack1).

> Lappalainen J.K., Tschopp F.D., Prakhya S., McGill M., Nern A., Shinomiya K., Takemura S., Gruntman E., Macke J.H., Turaga S.C., Connectome-constrained networks predict neural activity across the fly visual system. Nature 1–9 (2024).

### Funding

> This project was supported by the HHMI. J.K.L. and J.H.M. were supported by the German Research Foundation (DFG) through Germany’s Excellence Strategy (EXC-Number 2064/1, Project number 390727645), the German Federal Ministry of Education and Research (BMBF; Tübingen AI Center, FKZ: 01IS18039A) and the European Union (ERC, DeepCoMechTome, 101089288).


## Credits to colleagues

We extend credits to Jan Funke for an early discussion on the IO code. Roman Vaxenburg for the function `is_inside_hex` for more fine-grained control over stimulus rendering.
The whole new flyvis team at the Macke Lab for supporting the code cleanup and filling in tutorial notebooks.
Gert-Jan Both for general feedback and for pointing towards xarray and joblib for pruning of labeled tensor code and custom caching.

## Disclaimer on the usage of AI

The majority of the code in `flyvision` is based on code that we wrote before the widespread use of AI in scientific software development. Since our preprint was realeased in early 2023, we used AI in the last months to help us with in depth documentation. We tested the code to the best of our ability, but it might still contain errors. Please help us improve the code by [opening an issue](https://github.com/TuragaLab/flyvis/issues) on Github.

## Credits to open source software

[PyTorch](https://pytorch.org/), [NumPy](https://numpy.org/), [xarray](https://xarray.dev/),
[matplotlib](https://matplotlib.org/),[umap-learn](https://umap-learn.readthedocs.io/), [pandas](https://pandas.pydata.org/),
[scikit-learn](https://scikit-learn.org/), [scipy](https://scipy.org/), [omegaconf](https://omegaconf.readthedocs.io/),
[hydra](https://hydra.cc/), [networkx](https://networkx.org/), [toolz](https://toolz.readthedocs.io/en/latest/),
[joblib](https://joblib.readthedocs.io/)

## MIT License

> Copyright (c) 2023 Janne K. Lappalainen, Fabian D. Tschopp, Mason McGill, Jakob H. Macke, Srinivas C. Turaga
